// Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
// All rights reserved.
//
// This file is licensed according to the BSD 3-clause license as follows:
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of the "Linz Center of Mechatronics GmbH" and "LCM" nor
//       the names of its contributors may be used to endorse or promote products
//       derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL "Linz Center of Mechatronics GmbH" BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// This file is part of X2C. http://x2c.lcm.at/
// $LastChangedRevision: 2470 $
// $LastChangedDate:: 2022-02-15 21:54:32 +0100#$
//
// Function to create block icon for usage in palette browser.
// Parameters:
// libName - Library name
// blockName - Block name
// varargin - (optional) project root directory for external blocks

function [] = createBlockIcon(libName, blockName, varargin)

// import necessary java classes
jimport at.lcm.x2c.utils.LibraryUtils;

// get current directory
curDir = pwd();

// get XML file name and Xcos block name
if length(varargin) == 0 then
    // internal library
    libRoot = jinvoke(jinvoke(LibraryUtils, "getLibraryRootDirectory"), "toString");
    xmlPath = jinvoke(LibraryUtils, "getXmlDirectory", libName);
    xcosName = getXcosBlockName(libName, blockName);
else
    // external library
    libRoot = jinvoke(jinvoke(LibraryUtils, "getLibraryRootDirectory", varargin(1)), "toString");
    xmlPath = jinvoke(LibraryUtils, "getXmlDirectory", libName, libRoot);
    xcosName = getXcosBlockName(libName, blockName, varargin(1));
end
xmlDir = jinvoke(xmlPath, "toString");
cur_lib_root = fullfile(libRoot, libName);

xmlFileName = [xmlDir + blockName + ".xml"];
if ~isfile(xmlFileName) then
    disp("Error: could not find file " + xmlFileName);
    return; // exit script
end

// icon directory
icon_dir = fullfile(getLibraryScilabPath(cur_lib_root), "Icons");
// create icon directory if it does not exist
if ~isdir(icon_dir) then
    mkdir(icon_dir);
end

img_filename = fullfile(icon_dir, blockName + '.png');
try
    if isMajorVersionLessThan(6) then
        // block variable name has to be 'blk' in order to work with 'xcosPalGenerateIcon' included in Scilab 5.x
        execstr("blk = "+ xcosName + "('"define'");");
        xcosPalGenerateIcon(img_filename);
    else
        execstr("cur_block = "+ xcosName + "('"define'");");
        xcosPalGenerateIcon(cur_block, img_filename);
    end

    mprintf("Palette icon %s successfully created.\n", img_filename);
catch
    mprintf("Error creating Palette icon %s\n", img_filename);
    mprintf("ERROR: %s\n", lasterror());
end

endfunction
